# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Helix**, the nomination platform of ElecLink_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/eleclink-helix/platform-api) 

    The version of the OpenAPI document: 0.0.115
    Contact: team.eleclink@eleclink.co.uk
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List
from pydantic import BaseModel, Field, StrictStr, conlist

class BusinessProcessForkBlock(BaseModel):
    """
    BusinessProcessForkBlock
    """
    block_type: StrictStr = Field(..., alias="blockType")
    blocks: conlist(conlist(BusinessProcessContentBlock)) = Field(...)
    __properties = ["blockType", "blocks"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> BusinessProcessForkBlock:
        """Create an instance of BusinessProcessForkBlock from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in blocks (list of list)
        _items = []
        if self.blocks:
            for _item in self.blocks:
                if _item:
                    _items.append(
                         [_inner_item.to_dict() for _inner_item in _item if _inner_item is not None]
                    )
            _dict['blocks'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> BusinessProcessForkBlock:
        """Create an instance of BusinessProcessForkBlock from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return BusinessProcessForkBlock.parse_obj(obj)

        _obj = BusinessProcessForkBlock.parse_obj({
            "block_type": obj.get("blockType"),
            "blocks": [
                    [BusinessProcessContentBlock.from_dict(_inner_item) for _inner_item in _item]
                    for _item in obj.get("blocks")
                ] if obj.get("blocks") is not None else None
        })
        return _obj

from helix_platform_api_public_client.models.business_process_content_block import BusinessProcessContentBlock
BusinessProcessForkBlock.update_forward_refs()

