# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Helix**, the nomination platform of ElecLink_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/eleclink-helix/platform-api) 

    The version of the OpenAPI document: 0.0.115
    Contact: team.eleclink@eleclink.co.uk
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from helix_platform_api_public_client.models.timescale_nomination_options import TimescaleNominationOptions  # noqa: E501

class TestTimescaleNominationOptions(unittest.TestCase):
    """TimescaleNominationOptions unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> TimescaleNominationOptions:
        """Test TimescaleNominationOptions
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `TimescaleNominationOptions`
        """
        model = TimescaleNominationOptions()  # noqa: E501
        if include_optional:
            return TimescaleNominationOptions(
                window_timing = helix_platform_api_public_client.models.timescale_nomination_options_window_timing.TimescaleNominationOptions_windowTiming(
                    open_at = '2022-01-04T00:00Z', 
                    close_at = '2022-01-04T00:00Z', ),
                window_status = 'NOT_YET_OPEN',
                rights_in_directions = 'GB_FR'
            )
        else:
            return TimescaleNominationOptions(
                window_status = 'NOT_YET_OPEN',
                rights_in_directions = 'GB_FR',
        )
        """

    def testTimescaleNominationOptions(self):
        """Test TimescaleNominationOptions"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
